#line 1 "faustlexer.cpp"

#line 3 "faustlexer.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
typedef uint64_t flex_uint64_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                yy_size_t yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, yy_size_t len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (yy_size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 157
#define YY_END_OF_BUFFER 158
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[605] =
    {   0,
        0,    0,    2,    2,    0,    0,    0,    0,  158,  156,
      155,  155,   66,  156,   51,   54,   53,   69,   70,   49,
       47,   42,   48,   76,   50,   29,   41,   67,   59,   68,
       61,   52,  150,   73,   75,   74,  114,   65,  150,  150,
      150,  150,  150,  150,  150,  150,  150,  150,  150,  150,
      150,  150,  150,  150,  150,  150,  150,  150,   71,   55,
       72,   46,    2,    5,    6,    3,    9,   10,    9,  157,
       27,  157,   26,  157,  157,  157,  157,  155,   64,    0,
      151,   44,   37,    1,  154,   31,   29,    0,   30,    0,
       45,    0,    0,   43,   57,   60,  153,    0,    0,   63,

      141,   62,   58,  150,    0,  150,    0,  150,  150,  150,
      150,  150,  150,  150,  150,  150,  150,  150,  150,  150,
      150,  150,  150,  150,  150,  150,  150,  150,  150,  150,
      150,  150,  150,  150,  150,  150,  150,  150,  150,  150,
      150,  150,  150,  150,  150,  150,  150,  150,  150,  150,
      150,  150,  150,  150,  150,  150,  150,  150,  150,  150,
      150,  150,  150,  150,    2,    4,    3,    3,    7,    0,
        0,    0,    0,    0,    0,   28,    0,    0,    0,    0,
        0,    0,   38,  154,   31,    0,   32,    0,   35,  149,
        0,    0,    0,    0,    0,    0,    0,  117,  150,   84,

      150,  150,  150,  150,  150,  150,  150,  150,  150,  150,
      108,  150,  150,  150,  150,  111,  150,  150,  150,  150,
      150,  150,  150,  150,  150,  150,  150,  150,   82,  150,
      150,  112,  150,  119,   80,  118,  150,  150,  126,  115,
      150,  150,  150,  150,  150,  150,  150,  150,  150,  125,
      109,  150,  150,  127,  110,  150,  150,  150,  150,  150,
      150,  150,   56,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   39,    0,   33,   36,  149,
        0,  152,    0,    0,    0,    0,  150,    0,  104,  105,
      150,  106,  150,  150,  140,  123,  150,  150,  150,  150,

      150,  150,  150,  150,  150,  150,  150,  150,  120,  150,
      150,  150,  150,  150,  150,  150,  150,  150,  150,  150,
      150,  150,  150,  128,  150,  150,  150,  124,  150,  150,
      150,  150,  150,  116,  150,  150,  150,  150,  150,  150,
       77,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   21,   40,   34,    0,    0,    0,    0,    0,  150,
      150,  107,  150,  150,  150,  150,  150,  150,  150,  150,
      150,  150,  150,  150,   83,  122,  150,  150,  150,  150,
      150,  150,  150,  150,  150,  113,  150,  150,  150,  150,
      150,  150,  150,  136,  150,  150,  150,  150,  150,  150,

      150,  150,  150,   79,    0,    0,    0,    0,    0,    0,
        0,    0,   22,    0,  149,    0,    0,    0,    0,    8,
      150,  103,   92,  150,  150,  150,  150,  150,  137,  150,
      150,  150,  150,  150,  150,   98,  150,  150,  131,  129,
       78,  150,  143,   96,  150,   81,  150,  150,  150,  150,
      150,  150,  150,   99,  150,   97,  150,  150,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  149,    0,    0,
        0,  150,  150,  150,  138,  139,  150,  150,  150,  150,
      150,  150,  150,  144,   95,  133,  130,  150,   85,  150,
       86,   87,   88,  150,  150,  150,   94,  150,   20,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      150,   93,  150,  150,  150,  150,  150,  150,  150,  150,
      150,  150,  150,  150,  150,  135,    0,    0,   13,    0,
        0,    0,    0,    0,   24,    0,    0,    0,  150,  132,
      150,  150,   90,   89,  150,   91,  101,  150,  121,  150,
      102,  100,   16,    0,    0,    0,   11,    0,    0,   17,
        0,    0,  150,  150,  150,  150,  150,  150,   14,   18,
       12,    0,    0,   15,   19,  150,  150,  134,  150,  150,
      150,    0,   25,  142,  150,  150,  150,  150,   23,  150,
      150,  147,  150,  150,  150,  150,  146,  150,  145,  150,

      150,  150,  148,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    1,    1,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   23,   23,   23,   23,   23,   23,   24,   25,   26,
       27,   28,    1,   29,   30,   30,   30,   30,   30,   30,
       30,   30,   30,   30,   30,   30,   30,   30,   30,   30,
       30,   30,   30,   30,   30,   30,   30,   30,   30,   30,
       31,   32,   33,   34,   35,    1,   36,   37,   38,   39,

       40,   41,   42,   43,   44,   30,   45,   46,   47,   48,
       49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
       59,   30,   60,   61,   62,   63,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[64] =
    {   0,
        1,    1,    2,    2,    1,    1,    1,    1,    1,    1,
        1,    1,    3,    1,    1,    1,    4,    4,    5,    5,
        5,    5,    5,    6,    1,    4,    4,    4,    1,    7,
        1,    1,    1,    1,    8,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    1,
        1,    1,    1
    } ;

static const flex_int16_t yy_base[622] =
    {   0,
        0,    0,   61,   63,   65,   66,   63,   66, 1156, 1157,
       75,   83, 1128, 1147, 1157, 1157, 1157, 1157, 1157, 1157,
     1125, 1157, 1157,   75,   88,  102,   47, 1157,  109,   55,
       72, 1157, 1128, 1157, 1157, 1157, 1157, 1116,   91,   48,
      110,   92,   90,  116,  127,  128,  134,  137,  107,   94,
      143,  131,  158,  161,  164,  166,  185,  142, 1157, 1157,
     1157, 1157,    0, 1146, 1157,  152, 1157, 1157,  178, 1157,
     1157, 1121, 1157,   68, 1112, 1108, 1094,  228, 1157, 1138,
     1157, 1157,  215, 1157,    0,  220,  227,  243, 1157, 1109,
     1157,    0,  230, 1157, 1157, 1157, 1157,  254, 1104, 1157,

     1157, 1157, 1157, 1118, 1117, 1116, 1104,  160,  144,  163,
      170,  249,  221,  230,   65,  180,  252,  250,  203,  255,
      260,  263,  262,  265,  266,  269,  175,  268,  270,  271,
      273,  274,  277,  272,  283,  290,  278,  282,  285,  292,
      284,  297,  301,  304,  306,  310,  313,  311,  315,  317,
      321,  326,  322,  324,  319,  327,  328,  332,  330,  333,
      331,  338,  337,  341,    0, 1157,  368,  370, 1157, 1091,
     1093, 1085, 1091, 1094, 1084, 1157, 1082, 1078, 1084, 1080,
     1073,  376, 1157,    0,  381,  391, 1157,  396,  404, 1103,
     1091, 1097, 1080, 1072, 1082, 1072, 1085, 1095,  382, 1094,

      360,  345,  385,  396,  404,  349,  405,  406,  407,  410,
     1093,  413,  412,  415,  416, 1092,  414,  417,  423,  418,
      422,  419,  424,  426,   87,  429,  431,  339, 1091,  432,
      442,  448,  445, 1090, 1089, 1088,  446,  453, 1087, 1086,
      450,  454,  457,  459,  462,  455,  458,  463,  464, 1085,
      465,  466,  468, 1084, 1083,  477,  473,  478,  484,  481,
      482,  486, 1082, 1066, 1068, 1048, 1049, 1047, 1046, 1059,
     1044, 1044, 1058, 1055,  496,  516,  521,  526, 1157, 1070,
     1069, 1157, 1056, 1036, 1036, 1051, 1064, 1052, 1062, 1061,
      499,  509,  526,  507, 1060, 1059,  487,  528,  529,  530,

      534,  536,  531,  535,  537,  539,  538,  541, 1058,  545,
      544,  546,  547,  552,  548,  549,  550,  560,  575,  555,
      561,  571,  573, 1057,  574,  578,  581, 1056,  580,  582,
      583,  585,  588, 1055,  586,  587,  590,  594,  598,  592,
     1054, 1028, 1034, 1039, 1020, 1037, 1028, 1023, 1018, 1029,
     1014, 1157, 1157, 1157, 1032, 1024, 1029, 1028, 1035, 1038,
      599, 1037,  604,  606,  611,  610,  612,  613,  616,  619,
      614,  618,  620,  625, 1036, 1035,  626,  627,  628,  631,
      633,  622,  636,  642,  640, 1034,  643,  644,  645,  646,
      653,  647,  658, 1033,  661,  657,  662,  659,  663,  664,

      667,  670,  666, 1032, 1017, 1002,  999, 1008, 1012, 1012,
     1010, 1004, 1157, 1011, 1022, 1010,  992,  989, 1003, 1157,
      671, 1017, 1016,  672,  674,  677,  685,  688, 1015,  694,
      695,  696,  698,  700,  703, 1014,  702,  705, 1013, 1012,
     1011,  704, 1010, 1009,  706, 1008,  708,  709,  711,  712,
      722,  710,  717, 1007,  729, 1006,  721,  727, 1001,  992,
      983,  978,  989,  984,  983,  985,  979,  996,  983,  974,
      981,  731,  730,  734,  992,  991,  738,  740,  743,  744,
      742,  746,  745,  990,  989,  988,  987,  747,  986,  754,
      985,  984,  983,  748,  750,  751,  982,  752, 1157,  958,

      955,  961,  948,  779,  953,  945,  946,  951,  948,  942,
      753,  971,  757,  765,  774,  759,  778,  779,  780,  782,
      785,  783,  788,  791,  793,  970,  965,  944, 1157,  955,
      972,  961,  950,  909, 1157,  927,  900,  911,  786,  913,
      792,  794,  878,  877,  795,  876,  875,  797,  874,  799,
      873,  872, 1157,  867,  866,  865, 1157,  848,  851, 1157,
      861,  859,  800,  808,  809,  798,  814,  816, 1157, 1157,
     1157,  844,  841, 1157, 1157,  817,  819,  842,  821,  820,
      822,  471, 1157,  496,  823,  831,  829,  830, 1157,  827,
      840,  489,  832,  835,  838,  837,  229,  833,  228,  844,

      841,  855,  227, 1157,  903,  911,  919,  927,  932,  935,
      937,  945,  953,  961,  963,  182,  967,  969,  973,  975,
      979
    } ;

static const flex_int16_t yy_def[622] =
    {   0,
      604,    1,  605,  605,  606,  606,  607,  607,  604,  604,
      604,  604,  604,  608,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  609,  604,
      604,  604,  610,  604,  604,  604,  604,  611,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  604,  604,
      604,  604,  612,  604,  604,  613,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  608,
      604,  604,  604,  604,  614,  604,  604,  604,  604,  615,
      604,  616,  604,  604,  604,  604,  604,  609,   98,  604,

      604,  604,  604,  610,  604,  610,  611,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  612,  604,  613,  613,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  614,  604,  604,  604,  604,  604,  617,
      615,  604,  604,  604,  604,   98,  618,  610,  610,  610,

      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  604,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  617,
      604,  604,  604,  604,  604,   98,  619,  618,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,

      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  604,  620,  604,  604,  604,   98,  619,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,

      610,  610,  610,  610,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  604,  621,  620,  604,  604,  604,  604,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  621,  604,  604,
      604,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  604,  604,

      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  604,  604,  604,  604,  604,  604,  604,  604,
      604,  604,  610,  610,  610,  610,  610,  610,  604,  604,
      604,  604,  604,  604,  604,  610,  610,  610,  610,  610,
      610,  604,  604,  610,  610,  610,  610,  610,  604,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,

      610,  610,  610,    0,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      604
    } ;

static const flex_int16_t yy_nxt[1221] =
    {   0,
       10,   11,   12,   11,   11,   13,   14,   15,   16,   17,
       18,   19,   20,   21,   22,   23,   24,   25,   26,   26,
       26,   26,   26,   27,   28,   29,   30,   31,   32,   33,
       34,   35,   36,   37,   38,   39,   40,   41,   42,   43,
       44,   33,   45,   46,   33,   47,   48,   49,   50,   51,
       52,   53,   54,   55,   33,   56,   57,   58,   33,   59,
       60,   61,   62,   64,   65,   64,   65,   68,   68,   71,
       90,  105,   71,   66,   91,   66,   78,   78,   78,   78,
       72,  100,  101,   72,   78,   78,   78,   78,  105,   73,
       69,   69,   73,   83,   83,   83,   83,   83,  102,  103,

       84,   74,  113,   75,   74,   85,   75,  177,  207,   76,
      105,  178,   76,  105,  105,  105,   77,  105,   86,   77,
       87,   87,   87,   87,   87,   92,   93,  108,  109,  313,
      105,  118,   94,  105,   95,   96,   97,  120,  110,  105,
      119,   88,   89,  111,  112,  114,  140,  121,  141,  115,
      105,  105,  116,  122,  105,   99,  123,  105,  117,  124,
      105,  125,  126,  128,  168,  105,  105,  105,  129,  169,
      130,  127,  137,  134,  132,  133,  138,  135,  142,  131,
      139,  105,  136,  105,  105,  145,  105,  105,  192,  105,
      164,  143,  199,  105,  144,  170,  146,  147,  105,  156,

      151,  148,  158,  105,  152,  157,  149,  159,  105,  153,
      222,  154,  198,  201,  150,  155,  171,  172,  160,  208,
      161,  200,  202,  173,  174,  175,  105,  162,  163,   78,
       78,   78,   78,   83,   83,   83,   83,   83,  185,  185,
      185,  185,  185,   86,  105,   87,   87,   87,   87,   87,
      105,  105,  105,  105,  182,  183,  188,  213,  188,  186,
      187,  189,  189,  189,  189,  189,   88,   89,  193,  194,
       92,  604,  105,  105,  205,  105,  195,  604,  105,  604,
      604,   97,  206,  105,  203,  105,  105,  212,  105,  105,
      214,  105,  105,  105,  105,  105,  105,  105,  209,  210,

      105,  105,  204,  223,  211,  105,  105,  105,  105,  216,
      215,  217,  225,  105,  220,  105,  218,  221,  226,  231,
      105,  224,  219,  227,  105,  230,  228,  105,  235,  105,
      229,  232,  236,  105,  105,  234,  105,  238,  105,  237,
      105,  243,  105,  241,  105,  105,  233,  105,  239,  105,
      105,  105,  242,  105,  105,  105,  105,  240,  246,  245,
      105,  105,  105,  244,  105,  254,  249,  257,  105,  247,
      248,  250,  105,  251,  255,  253,  252,  261,  259,  256,
      604,  258,  168,  105,  291,  604,  260,  169,  295,  275,
      262,  275,  263,  316,  276,  276,  276,  276,  276,  185,

      185,  185,  185,  185,  277,  105,  277,  290,  105,  278,
      278,  278,  278,  278,  189,  189,  189,  189,  189,  105,
      186,  187,  189,  189,  189,  189,  189,  105,  105,  105,
      105,  293,  292,  105,  289,  105,  105,  105,  105,  105,
      105,  105,  105,  297,  279,  105,  105,  105,  301,  105,
      296,  302,  105,  307,  105,  105,  298,  294,  300,  303,
      309,  304,  306,  299,  305,  105,  308,  319,  105,  105,
      310,  105,  314,  105,  312,  311,  105,  105,  105,  315,
      105,  105,  105,  317,  320,  105,  105,  105,  105,  105,
      323,  105,  324,  318,  326,  325,  105,  327,  330,  321,

      105,  105,  322,  331,  105,  105,  332,  105,  328,  105,
      105,  329,  105,  333,  276,  276,  276,  276,  276,  105,
      339,  334,  105,  589,  336,  335,  337,  338,  341,  362,
      105,  365,  105,  340,  276,  276,  276,  276,  276,  278,
      278,  278,  278,  278,  278,  278,  278,  278,  278,  105,
      361,  105,  105,  105,  105,  364,  353,  105,  105,  105,
      105,  105,  105,  363,  105,  368,  354,  105,  105,  105,
      105,  105,  105,  105,  373,  105,  366,  374,  105,  369,
      367,  370,  371,  105,  105,  378,  380,  372,  377,  384,
      381,  375,  376,  386,  105,  385,  105,  105,  105,  382,

      379,  105,  383,  105,  105,  105,  105,  387,  105,  105,
      105,  105,  388,  105,  392,  105,  390,  105,  395,  394,
      396,  105,  105,  391,  393,  389,  398,  105,  400,  105,
      397,  404,  402,  105,  105,  105,  105,  105,  403,  105,
      399,  105,  105,  105,  401,  105,  422,  424,  105,  105,
      105,  105,  421,  423,  105,  428,  105,  425,  429,  105,
      426,  434,  430,  105,  427,  105,  105,  105,  105,  105,
      105,  431,  438,  432,  433,  439,  105,  436,  435,  441,
      105,  105,  105,  437,  105,  105,  105,  105,  440,  105,
      105,  442,  448,  105,  105,  105,  443,  105,  445,  453,

      105,  452,  444,  446,  447,  449,  450,  472,  105,  457,
      451,  105,  454,  474,  458,  455,  456,  105,  105,  105,
      473,  105,  475,  105,  476,  105,  105,  105,  105,  105,
      479,  105,  105,  105,  105,  105,  482,  477,  483,  480,
      105,  478,  492,  493,  105,  105,  481,  488,  489,  490,
      105,  491,  105,  105,  105,  484,  485,  105,  487,  494,
      495,  105,  486,  105,  496,  105,  105,  105,  105,  105,
      105,  105,  497,  105,  105,  105,  105,  105,  498,  511,
      105,  513,  105,  531,  521,  518,  515,  512,  105,  514,
      516,  519,  517,  522,  520,  524,  532,  105,  526,  523,

      525,  105,  105,  105,  541,  105,  105,  539,  105,  105,
      540,  105,  543,  542,  105,  105,  105,  105,  105,  546,
      105,  105,  105,  105,  547,  544,  545,  550,  548,  564,
      551,  105,  105,  563,  549,  552,  568,  105,  576,  105,
      105,  565,  105,  105,  105,  105,  105,  579,  566,  567,
      105,  577,  105,  105,  105,  105,  105,  580,  105,  581,
      105,  105,  578,  105,  105,  105,  590,  105,  587,  584,
      591,  585,  586,  593,  588,  594,  592,  595,  105,  583,
      596,  598,  597,  582,  599,  600,  575,  601,  574,  602,
      573,  572,  571,  570,  569,  105,  105,  105,  105,  105,

      105,  105,  603,   63,   63,   63,   63,   63,   63,   63,
       63,   67,   67,   67,   67,   67,   67,   67,   67,   70,
       70,   70,   70,   70,   70,   70,   70,   80,   80,   80,
       80,   80,   80,   80,   80,   98,  105,   98,   98,  104,
      104,  104,  104,  106,  106,  165,  562,  561,  165,  165,
      165,  165,  165,  167,  560,  167,  167,  167,  167,  167,
      167,  184,  559,  184,  184,  184,  184,  184,  184,  190,
      190,  280,  280,  280,  280,  287,  287,  360,  360,  360,
      360,  415,  415,  468,  468,  468,  468,  558,  557,  556,
      555,  554,  553,  105,  105,  538,  537,  536,  535,  534,

      533,  530,  529,  528,  527,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  105,  105,  510,  509,  508,  281,
      507,  506,  505,  504,  503,  502,  501,  500,  499,  105,
      105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
      105,  471,  470,  469,  416,  281,  467,  466,  465,  464,
      463,  462,  461,  460,  459,  105,  105,  105,  105,  105,
      105,  105,  420,  419,  418,  417,  416,  414,  413,  412,
      411,  410,  409,  408,  407,  406,  405,  105,  105,  105,
      105,  105,  105,  105,  105,  105,  288,  105,  359,  358,
      357,  356,  355,  281,  352,  351,  350,  349,  348,  347,

      346,  345,  344,  343,  342,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  105,  105,  105,  105,  105,  288,
      286,  285,  284,  283,  282,  191,  281,  274,  273,  272,
      271,  270,  269,  268,  267,  266,  265,  264,  107,  105,
      197,  105,  196,  191,   81,  181,  180,  179,  176,  166,
      107,  105,   82,   81,   79,  604,    9,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,

      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604
    } ;

static const flex_int16_t yy_chk[1221] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    3,    3,    4,    4,    5,    6,    7,
       27,   40,    8,    3,   27,    4,   11,   11,   11,   11,
        7,   30,   30,    8,   12,   12,   12,   12,  115,    7,
        5,    6,    8,   24,   24,   24,   24,   24,   31,   31,

       25,    7,   40,    7,    8,   25,    8,   74,  115,    7,
      225,   74,    8,   43,   39,   42,    7,   50,   26,    8,
       26,   26,   26,   26,   26,   29,   29,   39,   39,  225,
       49,   42,   29,   41,   29,   29,   29,   43,   39,   44,
       42,   26,   26,   39,   39,   41,   49,   43,   50,   41,
       45,   46,   41,   44,   52,   29,   44,   47,   41,   44,
       48,   44,   44,   45,   66,   58,   51,  109,   45,   66,
       45,   44,   48,   47,   46,   46,   48,   47,   51,   45,
       48,   53,   47,  108,   54,   52,  110,   55,  616,   56,
       58,   51,  109,  111,   51,   69,   53,   53,  127,   55,

       54,   53,   56,  116,   54,   55,   53,   56,   57,   54,
      127,   54,  108,  111,   53,   54,   69,   69,   56,  116,
       57,  110,  111,   69,   69,   69,  119,   57,   57,   78,
       78,   78,   78,   83,   83,   83,   83,   83,   86,   86,
       86,   86,   86,   87,  113,   87,   87,   87,   87,   87,
      603,  599,  597,  114,   83,   83,   88,  119,   88,   86,
       86,   88,   88,   88,   88,   88,   87,   87,   93,   93,
       98,   98,  112,  118,  113,  117,   93,   98,  120,   98,
       98,   98,  114,  121,  112,  123,  122,  118,  124,  125,
      120,  128,  126,  129,  130,  134,  131,  132,  117,  117,

      133,  137,  112,  128,  117,  138,  135,  141,  139,  121,
      120,  122,  130,  136,  125,  140,  123,  126,  131,  135,
      142,  129,  124,  132,  143,  134,  133,  144,  138,  145,
      133,  136,  139,  146,  148,  137,  147,  141,  149,  140,
      150,  145,  155,  144,  151,  153,  136,  154,  142,  152,
      156,  157,  144,  159,  161,  158,  160,  143,  148,  147,
      163,  162,  228,  146,  164,  155,  151,  158,  202,  149,
      150,  151,  206,  152,  156,  154,  153,  162,  160,  157,
      167,  159,  168,  201,  202,  167,  161,  168,  206,  182,
      163,  182,  164,  228,  182,  182,  182,  182,  182,  185,

      185,  185,  185,  185,  186,  199,  186,  201,  203,  186,
      186,  186,  186,  186,  188,  188,  188,  188,  188,  204,
      185,  185,  189,  189,  189,  189,  189,  205,  207,  208,
      209,  204,  203,  210,  199,  213,  212,  217,  214,  215,
      218,  220,  222,  208,  189,  221,  219,  223,  213,  224,
      207,  214,  226,  220,  227,  230,  209,  205,  212,  215,
      221,  217,  219,  210,  218,  231,  220,  232,  233,  237,
      222,  232,  226,  241,  224,  223,  238,  242,  246,  227,
      243,  247,  244,  230,  233,  245,  248,  249,  251,  252,
      241,  253,  242,  231,  244,  243,  257,  245,  248,  237,

      256,  258,  238,  249,  260,  261,  251,  259,  246,  262,
      297,  247,  592,  252,  275,  275,  275,  275,  275,  584,
      260,  253,  291,  582,  257,  256,  258,  259,  262,  292,
      294,  297,  292,  261,  276,  276,  276,  276,  276,  277,
      277,  277,  277,  277,  278,  278,  278,  278,  278,  293,
      291,  298,  299,  300,  303,  294,  276,  301,  304,  302,
      305,  307,  306,  293,  308,  300,  278,  311,  310,  312,
      313,  315,  316,  317,  305,  314,  298,  306,  320,  301,
      299,  302,  303,  318,  321,  311,  313,  304,  310,  317,
      314,  307,  308,  319,  322,  318,  323,  325,  319,  315,

      312,  326,  316,  329,  327,  330,  331,  320,  332,  335,
      336,  333,  321,  337,  326,  340,  323,  338,  330,  329,
      331,  339,  361,  325,  327,  322,  333,  363,  336,  364,
      332,  340,  338,  366,  365,  367,  368,  371,  339,  369,
      335,  372,  370,  373,  337,  382,  363,  365,  374,  377,
      378,  379,  361,  364,  380,  369,  381,  366,  370,  383,
      367,  377,  371,  385,  368,  384,  387,  388,  389,  390,
      392,  372,  381,  373,  374,  382,  391,  379,  378,  384,
      396,  393,  398,  380,  395,  397,  399,  400,  383,  403,
      401,  385,  392,  402,  421,  424,  387,  425,  389,  398,

      426,  397,  388,  390,  391,  393,  395,  421,  427,  402,
      396,  428,  399,  425,  403,  400,  401,  430,  431,  432,
      424,  433,  426,  434,  427,  437,  435,  442,  438,  445,
      431,  447,  448,  452,  449,  450,  434,  428,  435,  432,
      453,  430,  451,  451,  457,  451,  433,  447,  448,  449,
      458,  450,  455,  473,  472,  437,  438,  474,  445,  452,
      453,  477,  442,  478,  455,  481,  479,  480,  483,  482,
      488,  494,  457,  495,  496,  498,  511,  490,  458,  472,
      513,  474,  516,  504,  488,  481,  478,  473,  514,  477,
      479,  482,  480,  490,  483,  495,  504,  515,  498,  494,

      496,  517,  518,  519,  514,  520,  522,  511,  521,  539,
      513,  523,  516,  515,  524,  541,  525,  542,  545,  519,
      548,  566,  550,  563,  520,  517,  518,  523,  521,  541,
      524,  564,  565,  539,  522,  525,  550,  567,  563,  568,
      576,  542,  577,  580,  579,  581,  585,  566,  545,  548,
      590,  564,  587,  588,  586,  593,  598,  567,  594,  568,
      596,  595,  565,  591,  601,  578,  585,  600,  580,  576,
      586,  577,  579,  588,  581,  590,  587,  591,  602,  573,
      593,  595,  594,  572,  596,  598,  562,  600,  561,  601,
      559,  558,  556,  555,  554,  552,  551,  549,  547,  546,

      544,  543,  602,  605,  605,  605,  605,  605,  605,  605,
      605,  606,  606,  606,  606,  606,  606,  606,  606,  607,
      607,  607,  607,  607,  607,  607,  607,  608,  608,  608,
      608,  608,  608,  608,  608,  609,  540,  609,  609,  610,
      610,  610,  610,  611,  611,  612,  538,  537,  612,  612,
      612,  612,  612,  613,  536,  613,  613,  613,  613,  613,
      613,  614,  534,  614,  614,  614,  614,  614,  614,  615,
      615,  617,  617,  617,  617,  618,  618,  619,  619,  619,
      619,  620,  620,  621,  621,  621,  621,  533,  532,  531,
      530,  528,  527,  526,  512,  510,  509,  508,  507,  506,

      505,  503,  502,  501,  500,  497,  493,  492,  491,  489,
      487,  486,  485,  484,  476,  475,  471,  470,  469,  468,
      467,  466,  465,  464,  463,  462,  461,  460,  459,  456,
      454,  446,  444,  443,  441,  440,  439,  436,  429,  423,
      422,  419,  418,  417,  416,  415,  414,  412,  411,  410,
      409,  408,  407,  406,  405,  404,  394,  386,  376,  375,
      362,  360,  359,  358,  357,  356,  355,  351,  350,  349,
      348,  347,  346,  345,  344,  343,  342,  341,  334,  328,
      324,  309,  296,  295,  290,  289,  288,  287,  286,  285,
      284,  283,  281,  280,  274,  273,  272,  271,  270,  269,

      268,  267,  266,  265,  264,  263,  255,  254,  250,  240,
      239,  236,  235,  234,  229,  216,  211,  200,  198,  197,
      196,  195,  194,  193,  192,  191,  190,  181,  180,  179,
      178,  177,  175,  174,  173,  172,  171,  170,  107,  106,
      105,  104,   99,   90,   80,   77,   76,   75,   72,   64,
       38,   33,   21,   14,   13,    9,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,

      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604
    } ;

/* Table of booleans, true if rule could match eol. */
static const flex_int32_t yy_rule_can_match_eol[158] =
    {   0,
0, 0, 0, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "faustlexer.l"
/* -*- Mode: C++; tab-width: 4; c-basic-offset: 4 -*- */
/* Scanner for the Faust language */
#line 6 "faustlexer.l"
#include "tree.hh"
#include "faustparser.hpp"
#if defined(WIN32)
#if !defined(__MINGW32__) && !defined(__MSYS__)
// We don't want to include compatibility.hh here, since it pulls in whole lot
// of unneeded stuff which breaks other things, so here's some stuff to make
// MSVC happy.
#include <io.h>
#define isatty _isatty
#define fileno _fileno
#define YY_NO_UNISTD_H
#endif
#else
#include "compatibility.hh"
#include "errormsg.hh"

#define YY_FATAL_ERROR lexerror
#endif

#define register		// suppress the deprecated 'register' warning

#line 971 "faustlexer.cpp"

#line 973 "faustlexer.cpp"

#define INITIAL 0
#define comment 1
#define doc 2
#define lst 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			yy_size_t yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		yy_size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 45 "faustlexer.l"



#line 1195 "faustlexer.cpp"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 605 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1157 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			yy_size_t yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 48 "faustlexer.l"
BEGIN(comment);
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 49 "faustlexer.l"
/* eat anything that's not a '*' 		*/
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 50 "faustlexer.l"
/* eat up '*'s not followed by '/'s 	*/
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 51 "faustlexer.l"
/* no need to increment yylineno here 	*/
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 52 "faustlexer.l"
/* no need to increment yylineno here 	*/
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 53 "faustlexer.l"
/* no need to increment yylineno here 	*/
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 54 "faustlexer.l"
BEGIN(INITIAL);
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 56 "faustlexer.l"
{ BEGIN(doc); return BDOC; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 57 "faustlexer.l"
return DOCCHAR; /* char by char, may be slow ?? */
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 58 "faustlexer.l"
return DOCCHAR; /* keep newline chars */
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 59 "faustlexer.l"
return NOTICE;  /* autoclosing tag */
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 60 "faustlexer.l"
return NOTICE;  /* autoclosing tag */
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 61 "faustlexer.l"
{ BEGIN(lst);		return BLST; } /* autoclosing tag */
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 62 "faustlexer.l"
{ BEGIN(INITIAL); 	return BEQN; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 63 "faustlexer.l"
{ BEGIN(doc); 		return EEQN; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 64 "faustlexer.l"
{ BEGIN(INITIAL); 	return BDGM; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 65 "faustlexer.l"
{ BEGIN(doc); 		return EDGM; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 66 "faustlexer.l"
{ BEGIN(INITIAL); 	return BMETADATA; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 67 "faustlexer.l"
{ BEGIN(doc); 		return EMETADATA; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 68 "faustlexer.l"
{ BEGIN(INITIAL); 	return EDOC; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 70 "faustlexer.l"
return LSTTRUE;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 71 "faustlexer.l"
return LSTFALSE;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 72 "faustlexer.l"
return LSTDEPENDENCIES;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 73 "faustlexer.l"
return LSTMDOCTAGS;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 74 "faustlexer.l"
return LSTDISTRIBUTED;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 75 "faustlexer.l"
return LSTEQ;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 76 "faustlexer.l"
return LSTQ;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 77 "faustlexer.l"
{ BEGIN(doc); 	return ELST; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 80 "faustlexer.l"
return INT;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 82 "faustlexer.l"
return FLOAT;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 83 "faustlexer.l"
return FLOAT;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 84 "faustlexer.l"
return FLOAT;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 85 "faustlexer.l"
return FLOAT;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 86 "faustlexer.l"
return FLOAT;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 87 "faustlexer.l"
return FLOAT;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 88 "faustlexer.l"
return FLOAT;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 89 "faustlexer.l"
return FLOAT;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 90 "faustlexer.l"
return FLOAT;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 91 "faustlexer.l"
return FLOAT;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 92 "faustlexer.l"
return FLOAT;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 94 "faustlexer.l"
return SEQ;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 95 "faustlexer.l"
return PAR;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 96 "faustlexer.l"
return SPLIT;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 97 "faustlexer.l"
return MIX;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 98 "faustlexer.l"
return MIX;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 99 "faustlexer.l"
return REC;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 101 "faustlexer.l"
return ADD;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 102 "faustlexer.l"
return SUB;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 103 "faustlexer.l"
return MUL;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 104 "faustlexer.l"
return DIV;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 105 "faustlexer.l"
return MOD;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 106 "faustlexer.l"
return FDELAY;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 107 "faustlexer.l"
return DELAY1;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 109 "faustlexer.l"
return AND;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 110 "faustlexer.l"
return OR;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 111 "faustlexer.l"
return XOR;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 113 "faustlexer.l"
return LSH;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 114 "faustlexer.l"
return RSH;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 116 "faustlexer.l"
return LT;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 117 "faustlexer.l"
return LE;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 118 "faustlexer.l"
return GT;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 119 "faustlexer.l"
return GE;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 120 "faustlexer.l"
return EQ;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 121 "faustlexer.l"
return NE;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 123 "faustlexer.l"
return WIRE;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 124 "faustlexer.l"
return CUT;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 126 "faustlexer.l"
return ENDDEF;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 127 "faustlexer.l"
return DEF;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 128 "faustlexer.l"
return LPAR;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 129 "faustlexer.l"
return RPAR;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 130 "faustlexer.l"
return LBRAQ;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 131 "faustlexer.l"
return RBRAQ;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 132 "faustlexer.l"
return LCROC;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 133 "faustlexer.l"
return RCROC;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 135 "faustlexer.l"
return LAMBDA;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 136 "faustlexer.l"
return DOT;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 137 "faustlexer.l"
return WITH;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 138 "faustlexer.l"
return LETREC;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 139 "faustlexer.l"
return WHERE;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 141 "faustlexer.l"
return MEM;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 142 "faustlexer.l"
return PREFIX;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 144 "faustlexer.l"
return INTCAST;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 145 "faustlexer.l"
return FLOATCAST;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 146 "faustlexer.l"
return NOTYPECAST;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 148 "faustlexer.l"
return RDTBL;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 149 "faustlexer.l"
return RWTBL;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 151 "faustlexer.l"
return SELECT2;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 152 "faustlexer.l"
return SELECT3;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 154 "faustlexer.l"
return FFUNCTION;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 155 "faustlexer.l"
return FCONSTANT;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 156 "faustlexer.l"
return FVARIABLE;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 158 "faustlexer.l"
return BUTTON;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 159 "faustlexer.l"
return CHECKBOX;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 160 "faustlexer.l"
return VSLIDER;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 161 "faustlexer.l"
return HSLIDER;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 162 "faustlexer.l"
return NENTRY;
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 163 "faustlexer.l"
return VGROUP;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 164 "faustlexer.l"
return HGROUP;
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 165 "faustlexer.l"
return TGROUP;
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 166 "faustlexer.l"
return VBARGRAPH;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 167 "faustlexer.l"
return HBARGRAPH;
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 168 "faustlexer.l"
return SOUNDFILE;
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 170 "faustlexer.l"
return ATTACH;
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 172 "faustlexer.l"
return ACOS;
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 173 "faustlexer.l"
return ASIN;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 174 "faustlexer.l"
return ATAN;
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 175 "faustlexer.l"
return ATAN2;
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 177 "faustlexer.l"
return COS;
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 178 "faustlexer.l"
return SIN;
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 179 "faustlexer.l"
return TAN;
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 181 "faustlexer.l"
return EXP;
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 182 "faustlexer.l"
return LOG;
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 183 "faustlexer.l"
return LOG10;
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 184 "faustlexer.l"
return POWOP;
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 185 "faustlexer.l"
return POWFUN;
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 186 "faustlexer.l"
return SQRT;
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 188 "faustlexer.l"
return ABS;
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 189 "faustlexer.l"
return MIN;
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 190 "faustlexer.l"
return MAX;
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 192 "faustlexer.l"
return FMOD;
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 193 "faustlexer.l"
return REMAINDER;
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 195 "faustlexer.l"
return FLOOR;
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 196 "faustlexer.l"
return CEIL;
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 197 "faustlexer.l"
return RINT;
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 199 "faustlexer.l"
return ISEQ;
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 200 "faustlexer.l"
return IPAR;
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 201 "faustlexer.l"
return ISUM;
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 202 "faustlexer.l"
return IPROD;
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 204 "faustlexer.l"
return INPUTS;
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 205 "faustlexer.l"
return OUTPUTS;
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 207 "faustlexer.l"
return IMPORT;
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 208 "faustlexer.l"
return COMPONENT;
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 209 "faustlexer.l"
return LIBRARY;
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 210 "faustlexer.l"
return ENVIRONMENT;
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 212 "faustlexer.l"
return WAVEFORM;
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 213 "faustlexer.l"
return ROUTE;
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 214 "faustlexer.l"
return ENABLE;
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 215 "faustlexer.l"
return CONTROL;
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 217 "faustlexer.l"
return DECLARE;
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 219 "faustlexer.l"
return CASE;
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 220 "faustlexer.l"
return ARROW;
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 222 "faustlexer.l"
return ASSERTBOUNDS;
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 223 "faustlexer.l"
return LOWEST;
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 224 "faustlexer.l"
return HIGHEST;
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 226 "faustlexer.l"
return FLOATMODE;
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 227 "faustlexer.l"
return DOUBLEMODE;
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 228 "faustlexer.l"
return QUADMODE;
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 229 "faustlexer.l"
return FIXEDPOINTMODE;
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 232 "faustlexer.l"
return IDENT;
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 233 "faustlexer.l"
return IDENT;
	YY_BREAK
case 151:
/* rule 151 can match eol */
YY_RULE_SETUP
#line 235 "faustlexer.l"
return STRING;
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 237 "faustlexer.l"
return FSTRING;
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 238 "faustlexer.l"
return FSTRING;
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 241 "faustlexer.l"
/* eat up one-line comments */
	YY_BREAK
case 155:
/* rule 155 can match eol */
YY_RULE_SETUP
#line 243 "faustlexer.l"
/* eat up whitespace */
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(comment):
case YY_STATE_EOF(doc):
case YY_STATE_EOF(lst):
#line 245 "faustlexer.l"
yyterminate();
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 247 "faustlexer.l"
printf("extra text is : %s\n", yytext); return EXTRA;
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 250 "faustlexer.l"
ECHO;
	YY_BREAK
#line 2059 "faustlexer.cpp"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 605 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 605 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 604);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        yy_size_t yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 250 "faustlexer.l"

int yywrap() { return 1; }

